[Libreoffice-commits] .: bf_basic/source bf_starmath/source bf_svx/source bf_sw/source inc/bf_starmath inc/bf_sw

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Fri Oct 19 03:54:35 PDT 2012


 bf_basic/source/sbx/sbxbool.cxx         |    4 
 bf_basic/source/sbx/sbxbyte.cxx         |    4 
 bf_basic/source/sbx/sbxchar.cxx         |   24 +-
 bf_basic/source/sbx/sbxcurr.cxx         |    2 
 bf_basic/source/sbx/sbxdate.cxx         |    2 
 bf_basic/source/sbx/sbxdbl.cxx          |    2 
 bf_basic/source/sbx/sbxexec.cxx         |   32 +--
 bf_basic/source/sbx/sbxint.cxx          |    4 
 bf_basic/source/sbx/sbxlng.cxx          |    2 
 bf_basic/source/sbx/sbxscan.cxx         |    6 
 bf_basic/source/sbx/sbxsng.cxx          |    2 
 bf_basic/source/sbx/sbxuint.cxx         |    2 
 bf_basic/source/sbx/sbxulng.cxx         |    2 
 bf_basic/source/sbx/sbxvalue.cxx        |    6 
 bf_basic/source/sbx/sbxvar.cxx          |    4 
 bf_starmath/source/starmath_node.cxx    |   14 -
 bf_starmath/source/starmath_rect.cxx    |   22 +-
 bf_svx/source/editeng/impedit.hxx       |    2 
 bf_svx/source/editeng/svx_editdoc.cxx   |    6 
 bf_svx/source/editeng/svx_impedit3.cxx  |    2 
 bf_svx/source/form/svx_fmmodel.cxx      |    2 
 bf_sw/source/core/bastyp/sw_calc.cxx    |    4 
 bf_sw/source/core/inc/swfont.hxx        |   10 -
 bf_sw/source/core/text/inftxt.hxx       |   14 -
 bf_sw/source/core/text/porexp.hxx       |    4 
 bf_sw/source/core/text/porfld.hxx       |    2 
 bf_sw/source/core/text/portab.hxx       |   18 +-
 bf_sw/source/core/text/sw_guess.cxx     |    4 
 bf_sw/source/core/text/sw_inftxt.cxx    |    4 
 bf_sw/source/core/text/sw_itrform2.cxx  |    4 
 bf_sw/source/core/text/sw_porexp.cxx    |    4 
 bf_sw/source/core/text/sw_porfld.cxx    |    2 
 bf_sw/source/core/text/sw_porlay.cxx    |    2 
 bf_sw/source/core/text/sw_txtdrop.cxx   |    2 
 bf_sw/source/core/text/sw_txttab.cxx    |    6 
 bf_sw/source/core/txtnode/sw_ndtxt.cxx  |    4 
 bf_sw/source/core/txtnode/sw_txtedt.cxx |    4 
 inc/bf_starmath/node.hxx                |    8 
 inc/bf_starmath/types.hxx               |  278 ++++++++++++++++----------------
 inc/bf_sw/ndtxt.hxx                     |    4 
 40 files changed, 262 insertions(+), 262 deletions(-)

New commits:
commit e9e2d065b33d441ffa8838cc15f70a99155893de
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date:   Fri Oct 19 05:53:26 2012 -0500

    Change ucb_Unicode to sal_Unicode
    
    Change-Id: Ia48a9bf27e7495cb86fbbbc4b0edc2ff756075b9
    Reviewed-on: https://gerrit.libreoffice.org/889
    Reviewed-by: Norbert Thiebaud <nthiebaud at gmail.com>
    Tested-by: Norbert Thiebaud <nthiebaud at gmail.com>

diff --git a/bf_basic/source/sbx/sbxbool.cxx b/bf_basic/source/sbx/sbxbool.cxx
index 6fca8d8..0fc39f3 100644
--- a/bf_basic/source/sbx/sbxbool.cxx
+++ b/bf_basic/source/sbx/sbxbool.cxx
@@ -154,7 +154,7 @@ void ImpPutBool( SbxValues* p, INT16 n )
     switch( +p->eType )
     {
         case SbxCHAR:
-            p->nChar = (xub_Unicode) n; break;
+            p->nChar = (sal_Unicode) n; break;
         case SbxUINT:
             p->nByte = (BYTE) n; break;
         case SbxINTEGER:
@@ -204,7 +204,7 @@ void ImpPutBool( SbxValues* p, INT16 n )
             break;
         }
         case SbxBYREF | SbxCHAR:
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             *p->pByte = (BYTE) n; break;
         case SbxBYREF | SbxINTEGER:
diff --git a/bf_basic/source/sbx/sbxbyte.cxx b/bf_basic/source/sbx/sbxbyte.cxx
index a0ecf99..34397ae 100644
--- a/bf_basic/source/sbx/sbxbyte.cxx
+++ b/bf_basic/source/sbx/sbxbyte.cxx
@@ -266,7 +266,7 @@ void ImpPutByte( SbxValues* p, BYTE n )
             break;
 
         case SbxCHAR:
-            p->nChar = (xub_Unicode) n; break;
+            p->nChar = (sal_Unicode) n; break;
 
         case SbxBYREF | SbxSTRING:
         case SbxSTRING:
@@ -285,7 +285,7 @@ void ImpPutByte( SbxValues* p, BYTE n )
             break;
         }
         case SbxBYREF | SbxCHAR:
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             *p->pByte = n; break;
         case SbxBYREF | SbxINTEGER:
diff --git a/bf_basic/source/sbx/sbxchar.cxx b/bf_basic/source/sbx/sbxchar.cxx
index 866bc45..d0259e5 100644
--- a/bf_basic/source/sbx/sbxchar.cxx
+++ b/bf_basic/source/sbx/sbxchar.cxx
@@ -23,10 +23,10 @@
 
 namespace binfilter {
 
-xub_Unicode ImpGetChar( const SbxValues* p )
+sal_Unicode ImpGetChar( const SbxValues* p )
 {
     SbxValues aTmp;
-    xub_Unicode nRes;
+    sal_Unicode nRes;
 start:
     switch( +p->eType )
     {
@@ -37,7 +37,7 @@ start:
         case SbxCHAR:
             nRes = p->nChar; break;
         case SbxBYTE:
-            nRes = (xub_Unicode) p->nByte;
+            nRes = (sal_Unicode) p->nByte;
             break;
         case SbxINTEGER:
         case SbxBOOL:
@@ -46,11 +46,11 @@ start:
                 SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMINCHAR;
             }
             else
-                nRes = (xub_Unicode) p->nInteger;
+                nRes = (sal_Unicode) p->nInteger;
             break;
         case SbxERROR:
         case SbxUSHORT:
-            nRes = (xub_Unicode) p->nUShort;
+            nRes = (sal_Unicode) p->nUShort;
             break;
         case SbxLONG:
             if( p->nLong > SbxMAXCHAR )
@@ -62,7 +62,7 @@ start:
                 SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMINCHAR;
             }
             else
-                nRes = (xub_Unicode) p->nLong;
+                nRes = (sal_Unicode) p->nLong;
             break;
         case SbxULONG:
             if( p->nULong > SbxMAXCHAR )
@@ -70,7 +70,7 @@ start:
                 SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMAXCHAR;
             }
             else
-                nRes = (xub_Unicode) p->nULong;
+                nRes = (sal_Unicode) p->nULong;
             break;
         case SbxSALINT64:
             if( p->nInt64 > SbxMAXCHAR )
@@ -82,7 +82,7 @@ start:
                 SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMINCHAR;
             }
             else
-                nRes = (xub_Unicode) p->nInt64;
+                nRes = (sal_Unicode) p->nInt64;
             break;
         case SbxSALUINT64:
             if( p->uInt64 > SbxMAXCHAR )
@@ -90,7 +90,7 @@ start:
                 SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMAXCHAR;
             }
             else
-                nRes = (xub_Unicode) p->uInt64;
+                nRes = (sal_Unicode) p->uInt64;
             break;
         case SbxSINGLE:
             if( p->nSingle > SbxMAXCHAR )
@@ -102,7 +102,7 @@ start:
                 SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMINCHAR;
             }
             else
-                nRes = (xub_Unicode) ImpRound( p->nSingle );
+                nRes = (sal_Unicode) ImpRound( p->nSingle );
             break;
         case SbxDATE:
         case SbxDOUBLE:
@@ -160,7 +160,7 @@ start:
                     SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMINCHAR;
                 }
                 else
-                    nRes = (xub_Unicode) ImpRound( d );
+                    nRes = (sal_Unicode) ImpRound( d );
             }
             break;
         case SbxOBJECT:
@@ -214,7 +214,7 @@ start:
     return nRes;
 }
 
-void ImpPutChar( SbxValues* p, xub_Unicode n )
+void ImpPutChar( SbxValues* p, sal_Unicode n )
 {
     SbxValues aTmp;
 start:
diff --git a/bf_basic/source/sbx/sbxcurr.cxx b/bf_basic/source/sbx/sbxcurr.cxx
index 17c67f0..65be863 100644
--- a/bf_basic/source/sbx/sbxcurr.cxx
+++ b/bf_basic/source/sbx/sbxcurr.cxx
@@ -239,7 +239,7 @@ start:
             {
                 SbxBase::SetError( SbxERR_OVERFLOW ); dVal = SbxMINCHAR;
             }
-            *p->pChar = (xub_Unicode) dVal; break;
+            *p->pChar = (sal_Unicode) dVal; break;
         case SbxBYREF | SbxBYTE:
             if( dVal > SbxMAXBYTE )
             {
diff --git a/bf_basic/source/sbx/sbxdate.cxx b/bf_basic/source/sbx/sbxdate.cxx
index c1cc097..da2bacd 100644
--- a/bf_basic/source/sbx/sbxdate.cxx
+++ b/bf_basic/source/sbx/sbxdate.cxx
@@ -316,7 +316,7 @@ start:
             {
                 SbxBase::SetError( SbxERR_OVERFLOW ); n = SbxMINCHAR;
             }
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             if( n > SbxMAXBYTE )
             {
diff --git a/bf_basic/source/sbx/sbxdbl.cxx b/bf_basic/source/sbx/sbxdbl.cxx
index 69815ba..6719114 100644
--- a/bf_basic/source/sbx/sbxdbl.cxx
+++ b/bf_basic/source/sbx/sbxdbl.cxx
@@ -193,7 +193,7 @@ start:
             {
                 SbxBase::SetError( SbxERR_OVERFLOW ); n = SbxMINCHAR;
             }
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             if( n > SbxMAXBYTE )
             {
diff --git a/bf_basic/source/sbx/sbxexec.cxx b/bf_basic/source/sbx/sbxexec.cxx
index e80b8b6..c033777 100644
--- a/bf_basic/source/sbx/sbxexec.cxx
+++ b/bf_basic/source/sbx/sbxexec.cxx
@@ -47,10 +47,10 @@ public:
 
 
 static SbxVariable* Element
-    ( SbxObject* pObj, SbxObject* pGbl, const xub_Unicode** ppBuf,
+    ( SbxObject* pObj, SbxObject* pGbl, const sal_Unicode** ppBuf,
       SbxClassType, const SbxSimpleCharClass& rCharClass );
 
-static const xub_Unicode* SkipWhitespace( const xub_Unicode* p )
+static const sal_Unicode* SkipWhitespace( const sal_Unicode* p )
 {
     while( *p && ( *p == ' ' || *p == '\t' ) )
         p++;
@@ -60,7 +60,7 @@ static const xub_Unicode* SkipWhitespace( const xub_Unicode* p )
 // Scannen eines Symbol. Das Symbol wird in rSym eingetragen, der Returnwert
 // ist die neue Scanposition. Bei Fehlern ist das Symbol leer.
 
-static const xub_Unicode* Symbol( const xub_Unicode* p, XubString& rSym, const SbxSimpleCharClass& rCharClass )
+static const sal_Unicode* Symbol( const sal_Unicode* p, XubString& rSym, const SbxSimpleCharClass& rCharClass )
 {
     USHORT nLen = 0;
     // Haben wir ein Sondersymbol?
@@ -94,12 +94,12 @@ static const xub_Unicode* Symbol( const xub_Unicode* p, XubString& rSym, const S
 // Qualifizierter Name. Element.Element....
 
 static SbxVariable* QualifiedName
-    ( SbxObject* pObj, SbxObject* pGbl, const xub_Unicode** ppBuf, SbxClassType t )
+    ( SbxObject* pObj, SbxObject* pGbl, const sal_Unicode** ppBuf, SbxClassType t )
 {
     static SbxSimpleCharClass aCharClass;
 
     SbxVariableRef refVar;
-    const xub_Unicode* p = SkipWhitespace( *ppBuf );
+    const sal_Unicode* p = SkipWhitespace( *ppBuf );
     if( aCharClass.isAlpha( *p ) || *p == '_' || *p == '[' )
     {
         // Element einlesen
@@ -132,12 +132,12 @@ static SbxVariable* QualifiedName
 // eine Funktion (mit optionalen Parametern) sein.
 
 static SbxVariable* Operand
-    ( SbxObject* pObj, SbxObject* pGbl, const xub_Unicode** ppBuf, BOOL bVar )
+    ( SbxObject* pObj, SbxObject* pGbl, const sal_Unicode** ppBuf, BOOL bVar )
 {
     static SbxSimpleCharClass aCharClass;
 
     SbxVariableRef refVar( new SbxVariable );
-    const xub_Unicode* p = SkipWhitespace( *ppBuf );
+    const sal_Unicode* p = SkipWhitespace( *ppBuf );
     if( !bVar && ( aCharClass.isDigit( *p )
      || ( *p == '.' && aCharClass.isDigit( *( p+1 ) ) )
      || *p == '-'
@@ -179,14 +179,14 @@ static SbxVariable* Operand
 // Einlesen einer einfachen Term. Die Operatoren +, -, * und /
 // werden unterstuetzt.
 
-static SbxVariable* MulDiv( SbxObject* pObj, SbxObject* pGbl, const xub_Unicode** ppBuf )
+static SbxVariable* MulDiv( SbxObject* pObj, SbxObject* pGbl, const sal_Unicode** ppBuf )
 {
-    const xub_Unicode* p = *ppBuf;
+    const sal_Unicode* p = *ppBuf;
     SbxVariableRef refVar( Operand( pObj, pGbl, &p, FALSE ) );
     p = SkipWhitespace( p );
     while( refVar.Is() && ( *p == '*' || *p == '/' ) )
     {
-        xub_Unicode cOp = *p++;
+        sal_Unicode cOp = *p++;
         SbxVariableRef refVar2( Operand( pObj, pGbl, &p, FALSE ) );
         if( refVar2.Is() )
         {
@@ -211,14 +211,14 @@ static SbxVariable* MulDiv( SbxObject* pObj, SbxObject* pGbl, const xub_Unicode*
     return refVar;
 }
 
-static SbxVariable* PlusMinus( SbxObject* pObj, SbxObject* pGbl, const xub_Unicode** ppBuf )
+static SbxVariable* PlusMinus( SbxObject* pObj, SbxObject* pGbl, const sal_Unicode** ppBuf )
 {
-    const xub_Unicode* p = *ppBuf;
+    const sal_Unicode* p = *ppBuf;
     SbxVariableRef refVar( MulDiv( pObj, pGbl, &p ) );
     p = SkipWhitespace( p );
     while( refVar.Is() && ( *p == '+' || *p == '-' ) )
     {
-        xub_Unicode cOp = *p++;
+        sal_Unicode cOp = *p++;
         SbxVariableRef refVar2( MulDiv( pObj, pGbl, &p ) );
         if( refVar2.Is() )
         {
@@ -245,11 +245,11 @@ static SbxVariable* PlusMinus( SbxObject* pObj, SbxObject* pGbl, const xub_Unico
 
 
 static SbxVariable* Element
-    ( SbxObject* pObj, SbxObject* pGbl, const xub_Unicode** ppBuf,
+    ( SbxObject* pObj, SbxObject* pGbl, const sal_Unicode** ppBuf,
       SbxClassType t, const SbxSimpleCharClass& rCharClass )
 {
     XubString aSym;
-    const xub_Unicode* p = Symbol( *ppBuf, aSym, rCharClass );
+    const sal_Unicode* p = Symbol( *ppBuf, aSym, rCharClass );
     SbxVariableRef refVar;
     if( aSym.Len() )
     {
@@ -310,7 +310,7 @@ static SbxVariable* Element
 SbxVariable* SbxObject::FindQualified( const XubString& rName, SbxClassType t )
 {
     SbxVariable* pVar = NULL;
-    const xub_Unicode* p = rName.GetBuffer();
+    const sal_Unicode* p = rName.GetBuffer();
     p = SkipWhitespace( p );
     if( !*p )
         return NULL;;
diff --git a/bf_basic/source/sbx/sbxint.cxx b/bf_basic/source/sbx/sbxint.cxx
index 62aef92..33e3bc6 100644
--- a/bf_basic/source/sbx/sbxint.cxx
+++ b/bf_basic/source/sbx/sbxint.cxx
@@ -594,7 +594,7 @@ start:
             {
                 SbxBase::SetError( SbxERR_OVERFLOW ); n = SbxMINCHAR;
             }
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             if( n > SbxMAXBYTE )
             {
@@ -897,7 +897,7 @@ start:
             {
                 SbxBase::SetError( SbxERR_OVERFLOW ); n = SbxMAXCHAR;
             }
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             if( n > SbxMAXBYTE )
             {
diff --git a/bf_basic/source/sbx/sbxlng.cxx b/bf_basic/source/sbx/sbxlng.cxx
index e965259..991682e 100644
--- a/bf_basic/source/sbx/sbxlng.cxx
+++ b/bf_basic/source/sbx/sbxlng.cxx
@@ -254,7 +254,7 @@ start:
             {
                 SbxBase::SetError( SbxERR_OVERFLOW ); n = SbxMINCHAR;
             }
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             if( n > SbxMAXBYTE )
             {
diff --git a/bf_basic/source/sbx/sbxscan.cxx b/bf_basic/source/sbx/sbxscan.cxx
index daf3e8a..ff51433 100644
--- a/bf_basic/source/sbx/sbxscan.cxx
+++ b/bf_basic/source/sbx/sbxscan.cxx
@@ -465,10 +465,10 @@ static USHORT printfmtnum( double nNum, XubString& rRes, const XubString& rWFmt
     if( nLen > nWidth ) rRes += '%';
     else {
         nWidth -= nLen;
-        while( nWidth-- ) rRes += (xub_Unicode)cFill;
-        if( cPre ) rRes += (xub_Unicode)cPre;
+        while( nWidth-- ) rRes += (sal_Unicode)cFill;
+        if( cPre ) rRes += (sal_Unicode)cPre;
     }
-    rRes += (xub_Unicode*)&(cBuf[0]);
+    rRes += (sal_Unicode*)&(cBuf[0]);
     if( bTrail )
         rRes += bNeg ? '-' : ' ';
 
diff --git a/bf_basic/source/sbx/sbxsng.cxx b/bf_basic/source/sbx/sbxsng.cxx
index 69fa329..48c5b56 100644
--- a/bf_basic/source/sbx/sbxsng.cxx
+++ b/bf_basic/source/sbx/sbxsng.cxx
@@ -252,7 +252,7 @@ start:
             {
                 SbxBase::SetError( SbxERR_OVERFLOW ); n = SbxMINCHAR;
             }
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             if( n > SbxMAXBYTE )
             {
diff --git a/bf_basic/source/sbx/sbxuint.cxx b/bf_basic/source/sbx/sbxuint.cxx
index 5e08233..8c4c883 100644
--- a/bf_basic/source/sbx/sbxuint.cxx
+++ b/bf_basic/source/sbx/sbxuint.cxx
@@ -279,7 +279,7 @@ start:
         }
 
         case SbxBYREF | SbxCHAR:
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             if( n > SbxMAXBYTE )
             {
diff --git a/bf_basic/source/sbx/sbxulng.cxx b/bf_basic/source/sbx/sbxulng.cxx
index 04da31b..89a2e8c 100644
--- a/bf_basic/source/sbx/sbxulng.cxx
+++ b/bf_basic/source/sbx/sbxulng.cxx
@@ -256,7 +256,7 @@ start:
             {
                 SbxBase::SetError( SbxERR_OVERFLOW ); n = SbxMAXCHAR;
             }
-            *p->pChar = (xub_Unicode) n; break;
+            *p->pChar = (sal_Unicode) n; break;
         case SbxBYREF | SbxBYTE:
             if( n > SbxMAXBYTE )
             {
diff --git a/bf_basic/source/sbx/sbxvalue.cxx b/bf_basic/source/sbx/sbxvalue.cxx
index 1413d84..7b02785 100644
--- a/bf_basic/source/sbx/sbxvalue.cxx
+++ b/bf_basic/source/sbx/sbxvalue.cxx
@@ -288,7 +288,7 @@ SbxValue::SbxValue( SbxDataType t, void* p ) : SbxBase()
         case SbxUSHORT:
         case SbxBOOL:       n |= SbxBYREF; aData.pUShort = (UINT16*) p; break;
         case SbxULONG:      n |= SbxBYREF; aData.pULong = (UINT32*) p; break;
-        case SbxCHAR:       n |= SbxBYREF; aData.pChar = (xub_Unicode*) p; break;
+        case SbxCHAR:       n |= SbxBYREF; aData.pChar = (sal_Unicode*) p; break;
         case SbxBYTE:       n |= SbxBYREF; aData.pByte = (BYTE*) p; break;
         case SbxINT:        n |= SbxBYREF; aData.pInt = (int*) p; break;
         case SbxOBJECT:
@@ -653,7 +653,7 @@ BOOL SbxValue::GetBool() const
 t SbxValue::g() const { SbxValues aRes(e); Get( aRes ); return aRes.m; }
 
 GET( GetByte,     SbxBYTE,       BYTE,             nByte )
-GET( GetChar,     SbxCHAR,       xub_Unicode,           nChar )
+GET( GetChar,     SbxCHAR,       sal_Unicode,           nChar )
 GET( GetCurrency, SbxCURRENCY,   SbxINT64,         nLong64 )
 GET( GetDate,     SbxDATE,       double,           nDouble )
 GET( GetDouble,   SbxDOUBLE,     double,           nDouble )
@@ -812,7 +812,7 @@ BOOL SbxValue::p( t n ) \
 { SbxValues aRes(e); aRes.m = n; Put( aRes ); return BOOL( !IsError() ); }
 
 PUT( PutByte,     SbxBYTE,       BYTE,             nByte )
-PUT( PutChar,     SbxCHAR,       xub_Unicode,      nChar )
+PUT( PutChar,     SbxCHAR,       sal_Unicode,      nChar )
 PUT( PutCurrency, SbxCURRENCY,   const SbxINT64&,  nLong64 )
 PUT( PutDate,     SbxDATE,       double,           nDouble )
 PUT( PutDouble,   SbxDOUBLE,     double,           nDouble )
diff --git a/bf_basic/source/sbx/sbxvar.cxx b/bf_basic/source/sbx/sbxvar.cxx
index d14c324..a7fb01e 100644
--- a/bf_basic/source/sbx/sbxvar.cxx
+++ b/bf_basic/source/sbx/sbxvar.cxx
@@ -153,7 +153,7 @@ const XubString& SbxVariable::GetName( SbxNameType t ) const
     if( !pInfo
      || ( !pInfo->aParams.Count() && GetClass() == SbxCLASS_PROPERTY ) )
         return maName;
-    xub_Unicode cType = ' ';
+    sal_Unicode cType = ' ';
     XubString aTmp( maName );
     // Kurzer Typ? Dann holen, evtl. ist dieser 0.
     SbxDataType et = GetType();
@@ -228,7 +228,7 @@ USHORT SbxVariable::MakeHashCode( const XubString& rName )
     USHORT nLen = rName.Len();
     if( nLen > 6 )
         nLen = 6;
-    const xub_Unicode* p = rName.GetBuffer();
+    const sal_Unicode* p = rName.GetBuffer();
     while( nLen-- )
     {
         BYTE c = (BYTE)*p;
diff --git a/bf_starmath/source/starmath_node.cxx b/bf_starmath/source/starmath_node.cxx
index 586c005..926f814 100644
--- a/bf_starmath/source/starmath_node.cxx
+++ b/bf_starmath/source/starmath_node.cxx
@@ -1307,7 +1307,7 @@ void SmBinDiagonalNode::Arrange(const OutputDevice &rDev, const SmFormat &rForma
 /*N*/         aLclSize.Width() *= 182;
 /*N*/         aLclSize.Width() /= 267;
 /*N*/
-/*N*/       xub_Unicode cChar = pLeft->GetToken().cMathChar;
+/*N*/       sal_Unicode cChar = pLeft->GetToken().cMathChar;
 /*N*/       if (cChar != MS_LINE  &&  cChar != MS_DLINE)
 /*N*/           pLeft ->GetFont().SetSize(aLclSize);
 /*N*/
@@ -1964,7 +1964,7 @@ void SmRectangleNode::Draw(OutputDevice &rDev, const Point &rPosition) const
 
 /*N*/ void SmTextNode::Draw(OutputDevice &rDev, const Point& rPosition) const
 /*N*/ {
-/*N*/   if (IsPhantom()  ||  aText.Len() == 0  ||  aText.GetChar(0) == xub_Unicode('\0'))
+/*N*/   if (IsPhantom()  ||  aText.Len() == 0  ||  aText.GetChar(0) == sal_Unicode('\0'))
 /*N*/       return;
 /*N*/
 /*N*/     SmTmpDevice  aTmpDev ((OutputDevice &) rDev, FALSE);
@@ -2110,8 +2110,8 @@ void SmRectangleNode::Draw(OutputDevice &rDev, const Point &rPosition) const
 /*N*/ SmMathSymbolNode::SmMathSymbolNode(const SmToken &rNodeToken)
 /*N*/ : SmSpecialNode(NMATH, rNodeToken, FNT_MATH)
 /*N*/ {
-/*N*/   xub_Unicode cChar = GetToken().cMathChar;
-/*N*/   if ((xub_Unicode) '\0' != cChar)
+/*N*/   sal_Unicode cChar = GetToken().cMathChar;
+/*N*/   if ((sal_Unicode) '\0' != cChar)
 /*N*/       SetText( cChar );
 /*N*/ }
 
@@ -2191,7 +2191,7 @@ void SmRectangleNode::Draw(OutputDevice &rDev, const Point &rPosition) const
 /*N*/ {
 /*N*/   const XubString &rText = GetText();
 /*N*/
-/*N*/   if (rText.Len() == 0  ||  rText.GetChar(0) == xub_Unicode('\0'))
+/*N*/   if (rText.Len() == 0  ||  rText.GetChar(0) == sal_Unicode('\0'))
 /*N*/   {   SmRect::operator = (SmRect());
 /*N*/       return;
 /*N*/   }
@@ -2327,7 +2327,7 @@ void SmGlyphSpecialNode::Arrange(const OutputDevice &rDev, const SmFormat &rForm
 /*N*/   aTmpDev.SetFont(GetFont());
 /*N*/
 /*N*/   const XubString &rText = GetText();
-/*N*/   DBG_ASSERT(rText.Len() == 1  &&  rText.GetChar(0) == (xub_Unicode) MS_ERROR,
+/*N*/   DBG_ASSERT(rText.Len() == 1  &&  rText.GetChar(0) == (sal_Unicode) MS_ERROR,
 /*N*/               "Sm : Text ist kein ERROR Symbol");
 /*N*/   SmRect::operator = (SmRect(aTmpDev, &rFormat, rText, GetFont().GetBorderWidth()));
 /*N*/ }
@@ -2371,7 +2371,7 @@ void SmGlyphSpecialNode::Arrange(const OutputDevice &rDev, const SmFormat &rForm
 /*N*/         nSpace = nNum * nDist;
 /*N*/
 /*N*/   // ein SmRect mit Baseline und allem drum und dran besorgen
-/*N*/   SmRect::operator = (SmRect(aTmpDev, &rFormat, XubString(xub_Unicode(' ')),
+/*N*/   SmRect::operator = (SmRect(aTmpDev, &rFormat, XubString(sal_Unicode(' ')),
 /*N*/                              GetFont().GetBorderWidth()));
 /*N*/
 /*N*/   // und dieses auf die gewuenschte Breite bringen
diff --git a/bf_svx/source/editeng/impedit.hxx b/bf_svx/source/editeng/impedit.hxx
index 302693f..b40216e 100644
--- a/bf_svx/source/editeng/impedit.hxx
+++ b/bf_svx/source/editeng/impedit.hxx
@@ -729,7 +729,7 @@ inline Cursor* ImpEditView::GetCursor()
     return pCursor;
 }
 
-BYTE GetCharTypeForCompression( xub_Unicode cChar );
+BYTE GetCharTypeForCompression( sal_Unicode cChar );
 Point Rotate( const Point& rPoint, short nOrientation, const Point& rOrigin );
 
 }//end of namespace binfilter
diff --git a/bf_svx/source/editeng/svx_editdoc.cxx b/bf_svx/source/editeng/svx_editdoc.cxx
index b0d4206..ec94653 100644
--- a/bf_svx/source/editeng/svx_editdoc.cxx
+++ b/bf_svx/source/editeng/svx_editdoc.cxx
@@ -1192,13 +1192,13 @@ using namespace ::com::sun::star;
 /*N*/
 /*N*/   if ( nSepSize )
 /*N*/       nLen += nNodes * nSepSize;
-/*N*/   if ( nLen > 0xFFFb / sizeof(xub_Unicode) )
+/*N*/   if ( nLen > 0xFFFb / sizeof(sal_Unicode) )
 /*N*/   {
 /*?*/       OSL_FAIL( "Text zu gross fuer String" );
 /*?*/       return XubString();
 /*N*/   }
-/*N*/   xub_Unicode* pStr = new xub_Unicode[nLen+1];
-/*N*/   xub_Unicode* pCur = pStr;
+/*N*/   sal_Unicode* pStr = new sal_Unicode[nLen+1];
+/*N*/   sal_Unicode* pCur = pStr;
 /*N*/   USHORT nLastNode = nNodes-1;
 /*N*/   for ( USHORT nNode = 0; nNode < nNodes; nNode++ )
 /*N*/   {
diff --git a/bf_svx/source/editeng/svx_impedit3.cxx b/bf_svx/source/editeng/svx_impedit3.cxx
index f65e209..8ed9114 100644
--- a/bf_svx/source/editeng/svx_impedit3.cxx
+++ b/bf_svx/source/editeng/svx_impedit3.cxx
@@ -1604,7 +1604,7 @@ struct TabInfo
 /*N*/         String aWord = GetSelected( aWordSel );
 /*N*/         xub_StrLen nIdx = 0;
 /*N*/         xub_StrLen nKashidaPos = STRING_LEN;
-/*N*/         xub_Unicode cCh;
+/*N*/         sal_Unicode cCh;
 /*N*/
 /*N*/         while ( nIdx < aWord.Len() )
 /*N*/         {
diff --git a/bf_svx/source/form/svx_fmmodel.cxx b/bf_svx/source/form/svx_fmmodel.cxx
index fb5472f..05c519d 100644
--- a/bf_svx/source/form/svx_fmmodel.cxx
+++ b/bf_svx/source/form/svx_fmmodel.cxx
@@ -257,7 +257,7 @@ void FmFormModel::MovePage( USHORT, USHORT )
 /*N*/ {
 /*N*/   XubString sReturn = m_pImpl->sNextPageId;
 /*N*/
-/*N*/   xub_Unicode aNextChar = m_pImpl->sNextPageId.GetChar(m_pImpl->sNextPageId.Len() - 1);
+/*N*/   sal_Unicode aNextChar = m_pImpl->sNextPageId.GetChar(m_pImpl->sNextPageId.Len() - 1);
 /*N*/   sal_Bool bNeedNewChar = sal_False;
 /*N*/   switch (aNextChar)
 /*N*/   {
diff --git a/bf_sw/source/core/bastyp/sw_calc.cxx b/bf_sw/source/core/bastyp/sw_calc.cxx
index 9c96762..9bc84ca 100644
--- a/bf_sw/source/core/bastyp/sw_calc.cxx
+++ b/bf_sw/source/core/bastyp/sw_calc.cxx
@@ -1234,7 +1234,7 @@ static int
 /*N*/   if( !pLclD )
 /*N*/       pLclD = &GetAppLocaleData();
 /*N*/
-/*N*/   const xub_Unicode nCurrCmdPos = rCommandPos;
+/*N*/   const sal_Unicode nCurrCmdPos = rCommandPos;
 /*N*/     rtl_math_ConversionStatus eStatus;
 /*N*/     const sal_Unicode* pEnd;
 /*N*/     rVal = rtl_math_uStringToDouble( rCommand.GetBuffer() + rCommandPos,
@@ -1264,7 +1264,7 @@ static int
 /*N*/                           SvxCreateLocale( eLang ) );
 /*N*/   }
 /*N*/
-/*N*/   const xub_Unicode nCurrCmdPos = rCommandPos;
+/*N*/   const sal_Unicode nCurrCmdPos = rCommandPos;
 /*N*/     rtl_math_ConversionStatus eStatus;
 /*N*/     const sal_Unicode* pEnd;
 /*N*/     rVal = rtl_math_uStringToDouble( rCommand.GetBuffer() + rCommandPos,
diff --git a/bf_sw/source/core/inc/swfont.hxx b/bf_sw/source/core/inc/swfont.hxx
index 6326407..55fc55f 100644
--- a/bf_sw/source/core/inc/swfont.hxx
+++ b/bf_sw/source/core/inc/swfont.hxx
@@ -39,11 +39,11 @@ class SwScriptInfo;     // _GetTxtSize
 class ViewShell;
 class SwDoc;
 
-const xub_Unicode CH_BLANK = ' ';   // ' ' Leerzeichen
-const xub_Unicode CH_BREAK = 0x0A;  //
-const xub_Unicode CH_TAB   = '\t';  // \t
-const xub_Unicode CH_PAR    = 0xB6;     // Paragraph
-const xub_Unicode CH_BULLET = 0xB7;     // mittiger Punkt
+const sal_Unicode CH_BLANK = ' ';   // ' ' Leerzeichen
+const sal_Unicode CH_BREAK = 0x0A;  //
+const sal_Unicode CH_TAB   = '\t';  // \t
+const sal_Unicode CH_PAR    = 0xB6;     // Paragraph
+const sal_Unicode CH_BULLET = 0xB7;     // mittiger Punkt
 
 class SwSubFont : public SvxFont
 {
diff --git a/bf_sw/source/core/text/inftxt.hxx b/bf_sw/source/core/text/inftxt.hxx
index fa6fed7..2e8fcf0 100644
--- a/bf_sw/source/core/text/inftxt.hxx
+++ b/bf_sw/source/core/text/inftxt.hxx
@@ -271,7 +271,7 @@ public:
 
     inline const  SwViewOption &GetOpt() const { return *pOpt; }
     inline const XubString &GetTxt() const { return *pTxt; }
-    inline xub_Unicode GetChar( const xub_StrLen nPos ) const
+    inline sal_Unicode GetChar( const xub_StrLen nPos ) const
         { return pTxt->GetChar( nPos ); }
 
     inline KSHORT      GetTxtHeight() const;
@@ -491,8 +491,8 @@ class SwTxtFormatInfo : public SwTxtPaintInfo
                                 // info structure only pretends that we are at
                                 // the beginning of a line
 
-    xub_Unicode   cTabDecimal;  // das _aktuelle_ Dezimalzeichen
-    xub_Unicode   cHookChar;    // fuer Tabs in Feldern etc.
+    sal_Unicode   cTabDecimal;  // das _aktuelle_ Dezimalzeichen
+    sal_Unicode   cHookChar;    // fuer Tabs in Feldern etc.
     sal_uInt8   nMaxHyph;       // max. Zeilenanz. aufeinanderfolg. Trenn.
     sal_Bool   bTestFormat;     // Testformatierung aus WouldFit, keine Benachrichtigungen etc.
 
@@ -596,16 +596,16 @@ public:
     // Tabs
     inline SwTabPortion *GetLastTab() { return pLastTab; }
     inline void SetLastTab( SwTabPortion *pNew ) { pLastTab = pNew; }
-    inline xub_Unicode GetTabDecimal() const { return cTabDecimal; }
-    inline void SetTabDecimal( const xub_Unicode cNew ) { cTabDecimal = cNew;}
+    inline sal_Unicode GetTabDecimal() const { return cTabDecimal; }
+    inline void SetTabDecimal( const sal_Unicode cNew ) { cTabDecimal = cNew;}
 
     // Last*
     inline SwFldPortion *GetLastFld() { return pLastFld; }
     inline void SetLastFld( SwFldPortion *pNew ) { pLastFld = pNew; }
 
     inline void ClearHookChar() { cHookChar = 0; }
-    inline void SetHookChar( const xub_Unicode cNew ) { cHookChar = cNew; }
-    inline xub_Unicode GetHookChar() const { return cHookChar; }
+    inline void SetHookChar( const sal_Unicode cNew ) { cHookChar = cNew; }
+    inline sal_Unicode GetHookChar() const { return cHookChar; }
 
     // Done-Flags
     inline sal_Bool IsFtnDone() const { return bFtnDone; }
diff --git a/bf_sw/source/core/text/porexp.hxx b/bf_sw/source/core/text/porexp.hxx
index 14d4c88..c42860d 100644
--- a/bf_sw/source/core/text/porexp.hxx
+++ b/bf_sw/source/core/text/porexp.hxx
@@ -48,10 +48,10 @@ public:
 
 class SwBlankPortion : public SwExpandPortion
 {
-    xub_Unicode cChar;
+    sal_Unicode cChar;
     BOOL bMulti;        // For multiportion brackets
 public:
-    inline  SwBlankPortion( xub_Unicode cCh, BOOL bMult = sal_False )
+    inline  SwBlankPortion( sal_Unicode cCh, BOOL bMult = sal_False )
         : cChar( cCh ), bMulti( bMult )
         { cChar = cCh; SetLen(1); SetWhichPor( POR_BLANK ); }
 
diff --git a/bf_sw/source/core/text/porfld.hxx b/bf_sw/source/core/text/porfld.hxx
index a5f9a0d..e959458 100644
--- a/bf_sw/source/core/text/porfld.hxx
+++ b/bf_sw/source/core/text/porfld.hxx
@@ -141,7 +141,7 @@ public:
 class SwBulletPortion : public SwNumberPortion
 {
 public:
-    SwBulletPortion( const xub_Unicode cCh, SwFont *pFnt, const sal_Bool bLeft,
+    SwBulletPortion( const sal_Unicode cCh, SwFont *pFnt, const sal_Bool bLeft,
                      const sal_Bool bCenter, const KSHORT nMinDst );
     OUTPUT_OPERATOR
 };
diff --git a/bf_sw/source/core/text/portab.hxx b/bf_sw/source/core/text/portab.hxx
index a51bd48..2f74f97 100644
--- a/bf_sw/source/core/text/portab.hxx
+++ b/bf_sw/source/core/text/portab.hxx
@@ -29,12 +29,12 @@ namespace binfilter {
 class SwTabPortion : public SwFixPortion
 {
     const KSHORT nTabPos;
-    const xub_Unicode cFill;
+    const sal_Unicode cFill;
 
     // Das Format() verzweigt entweder in Pre- oder PostFormat()
     sal_Bool PreFormat( SwTxtFormatInfo &rInf );
 public:
-    SwTabPortion( const KSHORT nTabPos, const xub_Unicode cFill = '\0' );
+    SwTabPortion( const KSHORT nTabPos, const sal_Unicode cFill = '\0' );
     virtual sal_Bool Format( SwTxtFormatInfo &rInf );
     virtual void FormatEOL( SwTxtFormatInfo &rInf );
     sal_Bool PostFormat( SwTxtFormatInfo &rInf );
@@ -53,7 +53,7 @@ public:
 class SwTabLeftPortion : public SwTabPortion
 {
 public:
-    inline SwTabLeftPortion( const KSHORT nTabPos1, const xub_Unicode cFill1='\0' )
+    inline SwTabLeftPortion( const KSHORT nTabPos1, const sal_Unicode cFill1='\0' )
          : SwTabPortion( nTabPos1, cFill1 )
     { SetWhichPor( POR_TABLEFT ); }
     OUTPUT_OPERATOR
@@ -66,7 +66,7 @@ public:
 class SwTabRightPortion : public SwTabPortion
 {
 public:
-    inline SwTabRightPortion( const KSHORT nTabPos2, const xub_Unicode cFill2='\0' )
+    inline SwTabRightPortion( const KSHORT nTabPos2, const sal_Unicode cFill2='\0' )
          : SwTabPortion( nTabPos2, cFill2 )
     { SetWhichPor( POR_TABRIGHT ); }
     OUTPUT_OPERATOR
@@ -79,7 +79,7 @@ public:
 class SwTabCenterPortion : public SwTabPortion
 {
 public:
-    inline SwTabCenterPortion( const KSHORT nTabPos3, const xub_Unicode cFill3='\0' )
+    inline SwTabCenterPortion( const KSHORT nTabPos3, const sal_Unicode cFill3='\0' )
          : SwTabPortion( nTabPos3, cFill3 )
     { SetWhichPor( POR_TABCENTER ); }
     OUTPUT_OPERATOR
@@ -91,13 +91,13 @@ public:
 
 class SwTabDecimalPortion : public SwTabPortion
 {
-    const xub_Unicode cTab;
+    const sal_Unicode cTab;
 public:
-    inline SwTabDecimalPortion( const KSHORT nTabPos4, const xub_Unicode cInTab,
-                                const xub_Unicode cFill4 = '\0' )
+    inline SwTabDecimalPortion( const KSHORT nTabPos4, const sal_Unicode cInTab,
+                                const sal_Unicode cFill4 = '\0' )
          : SwTabPortion( nTabPos4, cFill4 ), cTab(cInTab)
     { SetWhichPor( POR_TABDECIMAL ); }
-    inline xub_Unicode GetTabDecimal() const { return cTab; }
+    inline sal_Unicode GetTabDecimal() const { return cTab; }
     OUTPUT_OPERATOR
 };
 
diff --git a/bf_sw/source/core/text/sw_guess.cxx b/bf_sw/source/core/text/sw_guess.cxx
index 8e01c8b..2e523a2 100644
--- a/bf_sw/source/core/text/sw_guess.cxx
+++ b/bf_sw/source/core/text/sw_guess.cxx
@@ -211,7 +211,7 @@ using rtl::OUString;
 /*M*/     xub_StrLen nPorLen = 0;
 /*M*/ #ifdef VERTICAL_LAYOUT
 /*M*/     // do not call the break iterator nCutPos is a blank
-/*M*/     xub_Unicode cCutChar = rInf.GetTxt().GetChar( nCutPos );
+/*M*/     sal_Unicode cCutChar = rInf.GetTxt().GetChar( nCutPos );
 /*M*/     if( CH_BLANK == cCutChar || CH_FULL_BLANK == cCutChar )
 /*M*/ #else
 /*M*/     if( CH_BLANK == rInf.GetTxt().GetChar( nCutPos ) )
@@ -257,7 +257,7 @@ using rtl::OUString;
 /*M*/
 /*M*/         xub_StrLen nOldIdx = rInf.GetIdx();
 /*M*/ #ifdef VERTICAL_LAYOUT
-/*M*/         xub_Unicode cFldChr = 0;
+/*M*/         sal_Unicode cFldChr = 0;
 /*M*/ #else
 /*M*/         sal_Char cFldChr = 0;
 /*M*/ #endif
diff --git a/bf_sw/source/core/text/sw_inftxt.cxx b/bf_sw/source/core/text/sw_inftxt.cxx
index b727a74..74de4db 100644
--- a/bf_sw/source/core/text/sw_inftxt.cxx
+++ b/bf_sw/source/core/text/sw_inftxt.cxx
@@ -656,12 +656,12 @@ extern Color aGlobalRetoucheColor;
 /*N*/                                             const xub_StrLen nEnd )
 /*N*/ {
 /*N*/   cHookChar = 0;
-/*N*/   const xub_Unicode cTabDec = GetLastTab() ? (sal_Unicode)GetTabDecimal() : 0;
+/*N*/   const sal_Unicode cTabDec = GetLastTab() ? (sal_Unicode)GetTabDecimal() : 0;
 /*N*/   xub_StrLen i = nStart;
 /*N*/
 /*N*/   for( ; i < nEnd; ++i )
 /*N*/   {
-/*N*/       const xub_Unicode cPos = GetChar( i );
+/*N*/       const sal_Unicode cPos = GetChar( i );
 /*N*/       switch( cPos )
 /*N*/       {
 /*N*/       case CH_TXTATR_BREAKWORD:
diff --git a/bf_sw/source/core/text/sw_itrform2.cxx b/bf_sw/source/core/text/sw_itrform2.cxx
index 65b502c..d61dbd9 100644
--- a/bf_sw/source/core/text/sw_itrform2.cxx
+++ b/bf_sw/source/core/text/sw_itrform2.cxx
@@ -1080,7 +1080,7 @@ extern sal_Bool IsUnderlineBreak( const SwLinePortion& rPor, const SwFont& rFnt
 /*M*/   if( !pPor )
 /*M*/   {
 /*M*/       // 5010: Tabs und Felder
-/*M*/       xub_Unicode cChar = rInf.GetHookChar();
+/*M*/       sal_Unicode cChar = rInf.GetHookChar();
 /*M*/
 /*M*/       if( cChar )
 /*M*/       {
@@ -1656,7 +1656,7 @@ extern sal_Bool IsUnderlineBreak( const SwLinePortion& rPor, const SwFont& rFnt
 /*N*/     const xub_StrLen nReformat = GetInfo().GetReformatStart();
 /*N*/     if( bOptimizeRepaint && STRING_LEN != nReformat )
 /*N*/   {
-/*N*/         const xub_Unicode cCh = GetInfo().GetTxt().GetChar( nReformat );
+/*N*/         const sal_Unicode cCh = GetInfo().GetTxt().GetChar( nReformat );
 /*N*/         bOptimizeRepaint = ( CH_TXTATR_BREAKWORD != cCh && CH_TXTATR_INWORD != cCh )
 /*N*/                             || ! GetInfo().HasHint( nReformat );
 /*N*/   }
diff --git a/bf_sw/source/core/text/sw_porexp.cxx b/bf_sw/source/core/text/sw_porexp.cxx
index de9591e..be4bba4 100644
--- a/bf_sw/source/core/text/sw_porexp.cxx
+++ b/bf_sw/source/core/text/sw_porexp.cxx
@@ -107,7 +107,7 @@ namespace binfilter {
 /*N*/           xub_StrLen nBlank = nIdx;
 /*N*/           while( --nBlank > rInf.GetLineStart() )
 /*N*/           {
-/*N*/               const xub_Unicode cCh = rInf.GetChar( nBlank );
+/*N*/               const sal_Unicode cCh = rInf.GetChar( nBlank );
 /*N*/               if( CH_BLANK == cCh ||
 /*N*/                   (( CH_TXTATR_BREAKWORD == cCh || CH_TXTATR_INWORD == cCh )
 /*N*/                       && rInf.HasHint( nBlank ) ) )
@@ -117,7 +117,7 @@ namespace binfilter {
 /*N*/               return 0;
 /*N*/       }
 /*N*/   }
-/*N*/   xub_Unicode cCh;
+/*N*/   sal_Unicode cCh;
 /*N*/   if( nIdx < 2 || CH_BLANK == (cCh = rInf.GetChar( nIdx - 1 )) )
 /*N*/       return 1;
 /*N*/   if( CH_BREAK == cCh )
diff --git a/bf_sw/source/core/text/sw_porfld.cxx b/bf_sw/source/core/text/sw_porfld.cxx
index 8151c49..510f80a 100644
--- a/bf_sw/source/core/text/sw_porfld.cxx
+++ b/bf_sw/source/core/text/sw_porfld.cxx
@@ -451,7 +451,7 @@ public:
  *                      class SwBulletPortion
  *************************************************************************/
 
-/*N*/ SwBulletPortion::SwBulletPortion( const xub_Unicode cBullet, SwFont *pFont,
+/*N*/ SwBulletPortion::SwBulletPortion( const sal_Unicode cBullet, SwFont *pFont,
 /*N*/                   const sal_Bool bLft, const sal_Bool bCntr, const KSHORT nMinDst )
 /*N*/   : SwNumberPortion( XubString( cBullet ), pFont, bLft, bCntr, nMinDst )
 /*N*/ {
diff --git a/bf_sw/source/core/text/sw_porlay.cxx b/bf_sw/source/core/text/sw_porlay.cxx
index 6a4beb0..13bff49 100644
--- a/bf_sw/source/core/text/sw_porlay.cxx
+++ b/bf_sw/source/core/text/sw_porlay.cxx
@@ -648,7 +648,7 @@ SwLinePortion *SwLineLayout::Insert( SwLinePortion *pIns )
 /*?*/
 /*?*/             while ( nLastCompression < nChg )
 /*?*/             {
-/*?*/                 xub_Unicode cChar = rTxt.GetChar( nLastCompression );
+/*?*/                 sal_Unicode cChar = rTxt.GetChar( nLastCompression );
 /*?*/
 /*?*/                 // examine current character
 /*?*/                 switch ( cChar )
diff --git a/bf_sw/source/core/text/sw_txtdrop.cxx b/bf_sw/source/core/text/sw_txtdrop.cxx
index c3e191b..5652136 100644
--- a/bf_sw/source/core/text/sw_txtdrop.cxx
+++ b/bf_sw/source/core/text/sw_txtdrop.cxx
@@ -138,7 +138,7 @@ using namespace ::com::sun::star;
 /*N*/     xub_StrLen i = 0;
 /*N*/     for( ; i < nEnd; ++i )
 /*N*/     {
-/*N*/         xub_Unicode cChar = GetTxt().GetChar( i );
+/*N*/         sal_Unicode cChar = GetTxt().GetChar( i );
 /*N*/         if( CH_TAB == cChar || CH_BREAK == cChar ||
 /*N*/             (( CH_TXTATR_BREAKWORD == cChar || CH_TXTATR_INWORD == cChar )
 /*N*/                 && SwTxtSizeInfo::_HasHint( this, i ) ) )
diff --git a/bf_sw/source/core/text/sw_txttab.cxx b/bf_sw/source/core/text/sw_txttab.cxx
index 13f3de2..2049fdc 100644
--- a/bf_sw/source/core/text/sw_txttab.cxx
+++ b/bf_sw/source/core/text/sw_txttab.cxx
@@ -91,8 +91,8 @@ namespace binfilter {
 /*N*/   if( nTabPos < rInf.X() )
 /*N*/       nTabPos = rInf.X();
 /*N*/
-/*N*/   xub_Unicode cFill = 0;
-/*N*/   xub_Unicode cDec = 0;
+/*N*/   sal_Unicode cFill = 0;
+/*N*/   sal_Unicode cDec = 0;
 /*N*/   SvxTabAdjust eAdj;
 /*N*/
 /*N*/   KSHORT nNewTabPos;
@@ -217,7 +217,7 @@ namespace binfilter {
 // Die Basisklasse wird erstmal ohne alles initialisiert.
 
 
-/*N*/ SwTabPortion::SwTabPortion( const KSHORT nTabPosition, const xub_Unicode cFillChar )
+/*N*/ SwTabPortion::SwTabPortion( const KSHORT nTabPosition, const sal_Unicode cFillChar )
 /*N*/   : SwFixPortion( 0, 0 ), nTabPos(nTabPosition), cFill(cFillChar)
 /*N*/ {
 /*N*/   nLineLength = 1;
diff --git a/bf_sw/source/core/txtnode/sw_ndtxt.cxx b/bf_sw/source/core/txtnode/sw_ndtxt.cxx
index 4fc6000..48d0e1f 100644
--- a/bf_sw/source/core/txtnode/sw_ndtxt.cxx
+++ b/bf_sw/source/core/txtnode/sw_ndtxt.cxx
@@ -1175,7 +1175,7 @@ SV_DECL_PTRARR(SwpHts,SwTxtAttr*,1,1)
 /*M*/         {
 /*M*/             xub_StrLen nI = 0;
 /*M*/             xub_StrLen nTmpPos = aPos;
-/*M*/             xub_Unicode cChar;
+/*M*/             sal_Unicode cChar;
 /*M*/
 /*M*/             while ( nI < rStr.Len() )
 /*M*/             {
@@ -2053,7 +2053,7 @@ SV_DECL_PTRARR(SwpHts,SwTxtAttr*,1,1)
  *************************************************************************/
 // Felder werden expandiert:
 
-/*N*/ void SwTxtNode::Replace( const SwIndex& rStart, xub_Unicode cCh )
+/*N*/ void SwTxtNode::Replace( const SwIndex& rStart, sal_Unicode cCh )
 /*N*/ {
 /*N*/
 /*N*/   OSL_ENSURE( rStart.GetIndex() < aText.Len(), "ausserhalb des Strings" );
diff --git a/inc/bf_starmath/node.hxx b/inc/bf_starmath/node.hxx
index 9114dce..ca43d97 100644
--- a/inc/bf_starmath/node.hxx
+++ b/inc/bf_starmath/node.hxx
@@ -354,8 +354,8 @@ protected:
     SmMathSymbolNode(SmNodeType eNodeType, const SmToken &rNodeToken)
     :   SmSpecialNode(eNodeType, rNodeToken, FNT_MATH)
     {
-        xub_Unicode cChar = GetToken().cMathChar;
-        if ((xub_Unicode) '\0' != cChar)
+        sal_Unicode cChar = GetToken().cMathChar;
+        if ((sal_Unicode) '\0' != cChar)
             SetText( cChar );
     }
 
@@ -398,7 +398,7 @@ public:
     SmPlaceNode(const SmToken &rNodeToken)
     :   SmMathSymbolNode(NPLACE, rNodeToken)
     {
-        SetText((xub_Unicode) MS_PLACE);
+        SetText((sal_Unicode) MS_PLACE);
     }
 
     virtual void Prepare(const SmFormat &rFormat, const SmDocShell &rDocShell);
@@ -415,7 +415,7 @@ public:
     SmErrorNode(SmParseError /*eError*/, const SmToken &rNodeToken)
     :   SmMathSymbolNode(NERROR, rNodeToken)
     {
-        SetText((xub_Unicode) MS_ERROR);
+        SetText((sal_Unicode) MS_ERROR);
     }
 
     virtual void Prepare(const SmFormat &rFormat, const SmDocShell &rDocShell);
diff --git a/inc/bf_starmath/types.hxx b/inc/bf_starmath/types.hxx
index f28dadf..8bdc5f2 100644
--- a/inc/bf_starmath/types.hxx
+++ b/inc/bf_starmath/types.hxx
@@ -36,145 +36,145 @@ enum SmPrintSize { PRINT_SIZE_NORMAL, PRINT_SIZE_SCALED, PRINT_SIZE_ZOOMED };
 //
 enum MathSymbol
 {
-    MS_FACT         = (xub_Unicode) 0x0021,
-    MS_INFINITY     = (xub_Unicode) 0x221E,
-    MS_SLASH        = (xub_Unicode) 0x002F,
-
-    MS_NDIVIDES     = (xub_Unicode) 0x2224,
-    MS_DRARROW      = (xub_Unicode) 0x21D2,
-    MS_DLARROW      = (xub_Unicode) 0x21D0,
-    MS_DLRARROW     = (xub_Unicode) 0x21D4,
-    MS_UNDERBRACE   = (xub_Unicode) 0xE081,
-    MS_OVERBRACE    = (xub_Unicode) 0xE082,
-    MS_CIRC         = (xub_Unicode) 0x00B0,
-    MS_ASSIGN       = (xub_Unicode) 0x003D,
-    MS_ERROR        = (xub_Unicode) 0x00BF,
-
-    MS_NEQ          = (xub_Unicode) 0x2260,
-    MS_PLUS         = (xub_Unicode) 0xE083,
-    MS_MINUS        = (xub_Unicode) 0x2212,
-    MS_MULTIPLY     = (xub_Unicode) 0x2217,
-    MS_TIMES        = (xub_Unicode) 0x00D7,
-    MS_CDOT         = (xub_Unicode) 0x22C5,
-    MS_DIV          = (xub_Unicode) 0x00F7,
-    MS_PLUSMINUS    = (xub_Unicode) 0x00B1,
-    MS_MINUSPLUS    = (xub_Unicode) 0x2213,
-    MS_OPLUS        = (xub_Unicode) 0x2295,
-    MS_OMINUS       = (xub_Unicode) 0x2296,
-    MS_OTIMES       = (xub_Unicode) 0x2297,
-    MS_ODIVIDE      = (xub_Unicode) 0x2298,
-    MS_ODOT         = (xub_Unicode) 0x2299,
-    MS_UNION        = (xub_Unicode) 0x222A,
-    MS_INTERSECT    = (xub_Unicode) 0x2229,
-
-    MS_LT           = (xub_Unicode) 0xE084,
-    MS_GT           = (xub_Unicode) 0xE085,
-    MS_LE           = (xub_Unicode) 0x2264,
-    MS_GE           = (xub_Unicode) 0x2265,
-    MS_LESLANT      = (xub_Unicode) 0xE086,
-    MS_GESLANT      = (xub_Unicode) 0xE087,
-    MS_LL           = (xub_Unicode) 0x226A,
-    MS_GG           = (xub_Unicode) 0x226B,
-    MS_SIM          = (xub_Unicode) 0x007E,
-    MS_SIMEQ        = (xub_Unicode) 0x2243,
-    MS_APPROX       = (xub_Unicode) 0x2248,
-    MS_DEF          = (xub_Unicode) 0x225D,
-    MS_EQUIV        = (xub_Unicode) 0x2261,
-    MS_PROP         = (xub_Unicode) 0x221D,
-    MS_PARTIAL      = (xub_Unicode) 0x2202,
-    MS_SUBSET       = (xub_Unicode) 0x2282,
-
-    MS_SUPSET       = (xub_Unicode) 0x2283,
-    MS_SUBSETEQ     = (xub_Unicode) 0x2286,
-    MS_SUPSETEQ     = (xub_Unicode) 0x2287,
-    MS_NSUBSET      = (xub_Unicode) 0x2284,
-    MS_NSUPSET      = (xub_Unicode) 0x2285,
-    MS_NSUBSETEQ    = (xub_Unicode) 0x2288,
-    MS_NSUPSETEQ    = (xub_Unicode) 0x2289,
-    MS_IN           = (xub_Unicode) 0x2208,
-    MS_NOTIN        = (xub_Unicode) 0x2209,
-    MS_EXISTS       = (xub_Unicode) 0x2203,
-    MS_BACKEPSILON  = (xub_Unicode) 0x220D,
-    MS_ALEPH        = (xub_Unicode) 0x2135,
-    MS_IM           = (xub_Unicode) 0x2111,
-    MS_RE           = (xub_Unicode) 0x211C,
-    MS_WP           = (xub_Unicode) 0x2118,
-
-    MS_LINE         = (xub_Unicode) 0x2223,
-    MS_DLINE        = (xub_Unicode) 0x2225,
-    MS_ORTHO        = (xub_Unicode) 0x22A5,
-    MS_DOTSLOW      = (xub_Unicode) 0xE08B,
-    MS_DOTSAXIS     = (xub_Unicode) 0x22EF,
-    MS_DOTSVERT     = (xub_Unicode) 0x22EE,
-    MS_DOTSUP       = (xub_Unicode) 0x22F0,
-    MS_DOTSDOWN     = (xub_Unicode) 0x22F1,
-    MS_TRANSR       = (xub_Unicode) 0x22B6,
-    MS_TRANSL       = (xub_Unicode) 0x22B7,
-    MS_RIGHTARROW   = (xub_Unicode) 0xE08C,
-    MS_BACKSLASH    = (xub_Unicode) 0x2216,
-    MS_NEG          = (xub_Unicode) 0x00AC,
-
-    MS_INT          = (xub_Unicode) 0x222B,
-    MS_IINT         = (xub_Unicode) 0x222C,
-    MS_IIINT        = (xub_Unicode) 0x222D,
-    MS_LINT         = (xub_Unicode) 0x222E,
-    MS_LLINT        = (xub_Unicode) 0x222F,
-    MS_LLLINT       = (xub_Unicode) 0x2230,
-    MS_SQRT         = (xub_Unicode) 0xE08D,
-    MS_SQRT2        = (xub_Unicode) 0xE08F,
-    MS_COPROD       = (xub_Unicode) 0x2210,
-    MS_PROD         = (xub_Unicode) 0x220F,
-    MS_SUM          = (xub_Unicode) 0x2211,
-    MS_NABLA        = (xub_Unicode) 0x2207,
-    MS_FORALL       = (xub_Unicode) 0x2200,
-
-    MS_HAT          = (xub_Unicode) 0xE091,
-    MS_CHECK        = (xub_Unicode) 0xE092,
-    MS_BREVE        = (xub_Unicode) 0xE093,
-    MS_ACUTE        = (xub_Unicode) 0xE094,
-    MS_GRAVE        = (xub_Unicode) 0xE095,
-    MS_TILDE        = (xub_Unicode) 0xE096,
-    MS_BAR          = (xub_Unicode) 0xE097,
-    MS_VEC          = (xub_Unicode) 0xE098,
-    MS_DOT          = (xub_Unicode) 0x02D9,
-    MS_DDOT         = (xub_Unicode) 0x00A8,
-    MS_DDDOT        = (xub_Unicode) 0xE09B,
-    MS_CIRCLE       = (xub_Unicode) 0x02DA,
-    MS_AND          = (xub_Unicode) 0x2227,
-    MS_OR           = (xub_Unicode) 0x2228,
-    MS_NI           = (xub_Unicode) 0x220B,
-    MS_EMPTYSET     = (xub_Unicode) 0x2205,
-
-    MS_LBRACE       = (xub_Unicode) 0x007B,
-    MS_RBRACE       = (xub_Unicode) 0x007D,
-    MS_LPARENT      = (xub_Unicode) 0xE09E,
-    MS_RPARENT      = (xub_Unicode) 0xE09F,
-    MS_LANGLE       = (xub_Unicode) 0x2329,
-    MS_RANGLE       = (xub_Unicode) 0x232A,
-    MS_LBRACKET     = (xub_Unicode) 0x005B,
-    MS_RBRACKET     = (xub_Unicode) 0x005D,
-
-    MS_LDBRACKET    = (xub_Unicode) 0x301A,
-    MS_RDBRACKET    = (xub_Unicode) 0x301B,
-    MS_PLACE        = (xub_Unicode) 0xE0AA,
-
-    MS_LCEIL        = (xub_Unicode) 0x2308,
-    MS_LFLOOR       = (xub_Unicode) 0x230A,
-    MS_RCEIL        = (xub_Unicode) 0x2309,
-    MS_RFLOOR       = (xub_Unicode) 0x230B,
-    MS_SQRT2_X      = (xub_Unicode) 0xE0AB,
-
-    MS_TOP          = (xub_Unicode) 0xE0D9,
-    MS_HBAR         = (xub_Unicode) 0x210F,
-    MS_LAMBDABAR    = (xub_Unicode) 0x019B,
-    MS_LEFTARROW    = (xub_Unicode) 0xE0DB,
-    MS_UPARROW      = (xub_Unicode) 0xE0DC,
-    MS_DOWNARROW    = (xub_Unicode) 0xE0DD,
-    MS_SETN         = (xub_Unicode) 0x2115,
-    MS_SETZ         = (xub_Unicode) 0x2124,
-    MS_SETQ         = (xub_Unicode) 0x211A,
-    MS_SETR         = (xub_Unicode) 0x211D,
-    MS_SETC         = (xub_Unicode) 0x2102
+    MS_FACT         = (sal_Unicode) 0x0021,
+    MS_INFINITY     = (sal_Unicode) 0x221E,
+    MS_SLASH        = (sal_Unicode) 0x002F,
+
+    MS_NDIVIDES     = (sal_Unicode) 0x2224,
+    MS_DRARROW      = (sal_Unicode) 0x21D2,
+    MS_DLARROW      = (sal_Unicode) 0x21D0,
+    MS_DLRARROW     = (sal_Unicode) 0x21D4,
+    MS_UNDERBRACE   = (sal_Unicode) 0xE081,
+    MS_OVERBRACE    = (sal_Unicode) 0xE082,
+    MS_CIRC         = (sal_Unicode) 0x00B0,
+    MS_ASSIGN       = (sal_Unicode) 0x003D,
+    MS_ERROR        = (sal_Unicode) 0x00BF,
+
+    MS_NEQ          = (sal_Unicode) 0x2260,
+    MS_PLUS         = (sal_Unicode) 0xE083,
+    MS_MINUS        = (sal_Unicode) 0x2212,
+    MS_MULTIPLY     = (sal_Unicode) 0x2217,
+    MS_TIMES        = (sal_Unicode) 0x00D7,
+    MS_CDOT         = (sal_Unicode) 0x22C5,
+    MS_DIV          = (sal_Unicode) 0x00F7,
+    MS_PLUSMINUS    = (sal_Unicode) 0x00B1,
+    MS_MINUSPLUS    = (sal_Unicode) 0x2213,
+    MS_OPLUS        = (sal_Unicode) 0x2295,
+    MS_OMINUS       = (sal_Unicode) 0x2296,
+    MS_OTIMES       = (sal_Unicode) 0x2297,
+    MS_ODIVIDE      = (sal_Unicode) 0x2298,
+    MS_ODOT         = (sal_Unicode) 0x2299,
+    MS_UNION        = (sal_Unicode) 0x222A,
+    MS_INTERSECT    = (sal_Unicode) 0x2229,
+
+    MS_LT           = (sal_Unicode) 0xE084,
+    MS_GT           = (sal_Unicode) 0xE085,
+    MS_LE           = (sal_Unicode) 0x2264,
+    MS_GE           = (sal_Unicode) 0x2265,
+    MS_LESLANT      = (sal_Unicode) 0xE086,
+    MS_GESLANT      = (sal_Unicode) 0xE087,
+    MS_LL           = (sal_Unicode) 0x226A,
+    MS_GG           = (sal_Unicode) 0x226B,
+    MS_SIM          = (sal_Unicode) 0x007E,
+    MS_SIMEQ        = (sal_Unicode) 0x2243,
+    MS_APPROX       = (sal_Unicode) 0x2248,
+    MS_DEF          = (sal_Unicode) 0x225D,
+    MS_EQUIV        = (sal_Unicode) 0x2261,
+    MS_PROP         = (sal_Unicode) 0x221D,
+    MS_PARTIAL      = (sal_Unicode) 0x2202,
+    MS_SUBSET       = (sal_Unicode) 0x2282,
+
+    MS_SUPSET       = (sal_Unicode) 0x2283,
+    MS_SUBSETEQ     = (sal_Unicode) 0x2286,
+    MS_SUPSETEQ     = (sal_Unicode) 0x2287,
+    MS_NSUBSET      = (sal_Unicode) 0x2284,
+    MS_NSUPSET      = (sal_Unicode) 0x2285,
+    MS_NSUBSETEQ    = (sal_Unicode) 0x2288,
+    MS_NSUPSETEQ    = (sal_Unicode) 0x2289,
+    MS_IN           = (sal_Unicode) 0x2208,
+    MS_NOTIN        = (sal_Unicode) 0x2209,
+    MS_EXISTS       = (sal_Unicode) 0x2203,
+    MS_BACKEPSILON  = (sal_Unicode) 0x220D,
+    MS_ALEPH        = (sal_Unicode) 0x2135,
+    MS_IM           = (sal_Unicode) 0x2111,
+    MS_RE           = (sal_Unicode) 0x211C,
+    MS_WP           = (sal_Unicode) 0x2118,
+
+    MS_LINE         = (sal_Unicode) 0x2223,
+    MS_DLINE        = (sal_Unicode) 0x2225,
+    MS_ORTHO        = (sal_Unicode) 0x22A5,
+    MS_DOTSLOW      = (sal_Unicode) 0xE08B,
+    MS_DOTSAXIS     = (sal_Unicode) 0x22EF,
+    MS_DOTSVERT     = (sal_Unicode) 0x22EE,
+    MS_DOTSUP       = (sal_Unicode) 0x22F0,
+    MS_DOTSDOWN     = (sal_Unicode) 0x22F1,
+    MS_TRANSR       = (sal_Unicode) 0x22B6,
+    MS_TRANSL       = (sal_Unicode) 0x22B7,
+    MS_RIGHTARROW   = (sal_Unicode) 0xE08C,
+    MS_BACKSLASH    = (sal_Unicode) 0x2216,
+    MS_NEG          = (sal_Unicode) 0x00AC,
+
+    MS_INT          = (sal_Unicode) 0x222B,
+    MS_IINT         = (sal_Unicode) 0x222C,
+    MS_IIINT        = (sal_Unicode) 0x222D,
+    MS_LINT         = (sal_Unicode) 0x222E,
+    MS_LLINT        = (sal_Unicode) 0x222F,
+    MS_LLLINT       = (sal_Unicode) 0x2230,
+    MS_SQRT         = (sal_Unicode) 0xE08D,
+    MS_SQRT2        = (sal_Unicode) 0xE08F,
+    MS_COPROD       = (sal_Unicode) 0x2210,
+    MS_PROD         = (sal_Unicode) 0x220F,
+    MS_SUM          = (sal_Unicode) 0x2211,
+    MS_NABLA        = (sal_Unicode) 0x2207,
+    MS_FORALL       = (sal_Unicode) 0x2200,
+
+    MS_HAT          = (sal_Unicode) 0xE091,
+    MS_CHECK        = (sal_Unicode) 0xE092,
+    MS_BREVE        = (sal_Unicode) 0xE093,
+    MS_ACUTE        = (sal_Unicode) 0xE094,
+    MS_GRAVE        = (sal_Unicode) 0xE095,
+    MS_TILDE        = (sal_Unicode) 0xE096,
+    MS_BAR          = (sal_Unicode) 0xE097,
+    MS_VEC          = (sal_Unicode) 0xE098,
+    MS_DOT          = (sal_Unicode) 0x02D9,
+    MS_DDOT         = (sal_Unicode) 0x00A8,
+    MS_DDDOT        = (sal_Unicode) 0xE09B,
+    MS_CIRCLE       = (sal_Unicode) 0x02DA,
+    MS_AND          = (sal_Unicode) 0x2227,
+    MS_OR           = (sal_Unicode) 0x2228,
+    MS_NI           = (sal_Unicode) 0x220B,
+    MS_EMPTYSET     = (sal_Unicode) 0x2205,
+
+    MS_LBRACE       = (sal_Unicode) 0x007B,
+    MS_RBRACE       = (sal_Unicode) 0x007D,
+    MS_LPARENT      = (sal_Unicode) 0xE09E,
+    MS_RPARENT      = (sal_Unicode) 0xE09F,
+    MS_LANGLE       = (sal_Unicode) 0x2329,
+    MS_RANGLE       = (sal_Unicode) 0x232A,
+    MS_LBRACKET     = (sal_Unicode) 0x005B,
+    MS_RBRACKET     = (sal_Unicode) 0x005D,
+
+    MS_LDBRACKET    = (sal_Unicode) 0x301A,
+    MS_RDBRACKET    = (sal_Unicode) 0x301B,
+    MS_PLACE        = (sal_Unicode) 0xE0AA,
+
+    MS_LCEIL        = (sal_Unicode) 0x2308,
+    MS_LFLOOR       = (sal_Unicode) 0x230A,
+    MS_RCEIL        = (sal_Unicode) 0x2309,
+    MS_RFLOOR       = (sal_Unicode) 0x230B,
+    MS_SQRT2_X      = (sal_Unicode) 0xE0AB,
+
+    MS_TOP          = (sal_Unicode) 0xE0D9,
+    MS_HBAR         = (sal_Unicode) 0x210F,
+    MS_LAMBDABAR    = (sal_Unicode) 0x019B,
+    MS_LEFTARROW    = (sal_Unicode) 0xE0DB,
+    MS_UPARROW      = (sal_Unicode) 0xE0DC,
+    MS_DOWNARROW    = (sal_Unicode) 0xE0DD,
+    MS_SETN         = (sal_Unicode) 0x2115,
+    MS_SETZ         = (sal_Unicode) 0x2124,
+    MS_SETQ         = (sal_Unicode) 0x211A,
+    MS_SETR         = (sal_Unicode) 0x211D,
+    MS_SETC         = (sal_Unicode) 0x2102
 };
 
 
diff --git a/inc/bf_sw/ndtxt.hxx b/inc/bf_sw/ndtxt.hxx
index 9531051..97ba5f3 100644
--- a/inc/bf_sw/ndtxt.hxx
+++ b/inc/bf_sw/ndtxt.hxx
@@ -122,7 +122,7 @@ public:
      * Einfuegen anderer Datentypen durch Erzeugen eines
      * temporaeren Strings.
      */
-    SwTxtNode&  Insert( xub_Unicode c, const SwIndex &rIdx );
+    SwTxtNode&  Insert( sal_Unicode c, const SwIndex &rIdx );
     SwTxtNode&  Insert( const XubString &rStr, const SwIndex &rIdx,
                         const USHORT nMode = INS_DEFAULT );
 
@@ -174,7 +174,7 @@ public:
     inline void Cut(SwTxtNode *pDest, const SwIndex &rDestStart,
                     const SwIndex &rStart, xub_StrLen nLen);
     // ersetze im String an Position nIdx das Zeichen
-    void Replace( const SwIndex& rStart, xub_Unicode cCh );
+    void Replace( const SwIndex& rStart, sal_Unicode cCh );
 
     // virtuelle Methoden aus dem CntntNode
     virtual SwCntntFrm *MakeFrm();


More information about the Libreoffice-commits mailing list
diff --git a/bf_starmath/source/starmath_rect.cxx b/bf_starmath/source/starmath_rect.cxx
index 61bba01..5aa82f9 100644
--- a/bf_starmath/source/starmath_rect.cxx
+++ b/bf_starmath/source/starmath_rect.cxx
@@ -45,17 +45,17 @@ namespace binfilter {
 // '\0' terminiertes Array mit Zeichen, die im StarMath Font als Buchstaben
 // betrachtet werden sollen, (um im Gegensatz zu den anderen Operatoren
 // und Symbolen ein "normales"(ungecliptes) SmRect zu erhalten).
-static xub_Unicode const aMathAlpha[] =
+static sal_Unicode const aMathAlpha[] =
 {
     MS_ALEPH,               MS_IM,                  MS_RE,
-    MS_WP,                  xub_Unicode(0xE070),    MS_EMPTYSET,
-    xub_Unicode(0x2113),    xub_Unicode(0xE0D6),    xub_Unicode(0x2107),
-    xub_Unicode(0x2127),    xub_Unicode(0x210A),    MS_HBAR,
+    MS_WP,                  sal_Unicode(0xE070),    MS_EMPTYSET,
+    sal_Unicode(0x2113),    sal_Unicode(0xE0D6),    sal_Unicode(0x2107),
+    sal_Unicode(0x2127),    sal_Unicode(0x210A),    MS_HBAR,
     MS_LAMBDABAR,           MS_SETN,                MS_SETZ,
     MS_SETQ,                MS_SETR,                MS_SETC,
-    xub_Unicode(0x2373),    xub_Unicode(0xE0A5),    xub_Unicode(0x2112),
-    xub_Unicode(0x2130),    xub_Unicode(0x2131),
-    xub_Unicode('\0')
+    sal_Unicode(0x2373),    sal_Unicode(0xE0A5),    sal_Unicode(0x2112),
+    sal_Unicode(0x2130),    sal_Unicode(0x2131),
+    sal_Unicode('\0')
 };
 
 /*N*/ BOOL SmIsMathAlpha(const XubString &rText)
@@ -66,18 +66,18 @@ static xub_Unicode const aMathAlpha[] =
 /*N*/       return FALSE;
 /*N*/
 /*N*/   DBG_ASSERT(rText.Len() == 1, "Sm : String enthaelt nicht genau ein Zeichen");
-/*N*/   xub_Unicode cChar = rText.GetChar(0);
+/*N*/   sal_Unicode cChar = rText.GetChar(0);
 /*N*/
 /*N*/   // ist es ein griechisches Zeichen ?
 /*N*/     if (xub_Unicode(0xE0AC) <= cChar  &&  cChar <= xub_Unicode(0xE0D4))
 /*N*/       return TRUE;
 /*N*/   else
 /*N*/   {
 /*N*/       // kommt es in 'aMathAlpha' vor ?
-/*N*/       const xub_Unicode *pChar = aMathAlpha;
+/*N*/       const sal_Unicode *pChar = aMathAlpha;
 /*N*/       while (*pChar  &&  *pChar != cChar)
 /*N*/           pChar++;
-/*N*/       return *pChar != xub_Unicode('\0');
+/*N*/       return *pChar != sal_Unicode('\0');
 /*N*/   }
 /*N*/ }
 
@@ -66,18 +66,18 @@ static xub_Unicode const aMathAlpha[] =
 /*N*/
 /*N*/   // ist es ein griechisches Zeichen ?
-/*N*/     if (xub_Unicode(0xE0AC) <= cChar  &&  cChar <= xub_Unicode(0xE0D4))
+/*N*/     if (sal_Unicode(0xE0AC) <= cChar  &&  cChar <= sal_Unicode(0xE0D4))
 /*N*/       return TRUE;
 /*N*/   else
diff --git a/bf_sw/source/core/txtnode/sw_txtedt.cxx b/bf_sw/source/core/txtnode/sw_txtedt.cxx
index 3d72b15..7ab1227 100644
--- a/bf_sw/source/core/txtnode/sw_txtedt.cxx
+++ b/bf_sw/source/core/txtnode/sw_txtedt.cxx
@@ -64,7 +64,7 @@ using namespace ::com::sun::star::linguistic2;
 extern const SwTxtNode *pLinguNode;
 extern       SwTxtFrm  *pLinguFrm;
 
-bool lcl_IsSkippableWhiteSpace( xub_Unicode cCh )
+bool lcl_IsSkippableWhiteSpace( sal_Unicode cCh )
 {
     return 0x3000 == cCh ||
            ' ' == cCh ||
@@ -76,7 +76,7 @@ bool lcl_IsSkippableWhiteSpace( xub_Unicode cCh )
  * Ein Zeichen wurde eingefuegt.
  */
 
 /*N*/ SwTxtNode& SwTxtNode::Insert( xub_Unicode c, const SwIndex &rIdx )
 /*N*/ {
 /*N*/   xub_StrLen nOrigLen = aText.Len();
 /*N*/
@@ -76,7 +76,7 @@ bool lcl_IsSkippableWhiteSpace( xub_Unicode cCh )
  */
 
-/*N*/ SwTxtNode& SwTxtNode::Insert( xub_Unicode c, const SwIndex &rIdx )
+/*N*/ SwTxtNode& SwTxtNode::Insert( sal_Unicode c, const SwIndex &rIdx )
 /*N*/ {
 /*N*/   xub_StrLen nOrigLen = aText.Len();